@@ -1,23 +1,24 @@
 #' Remove variable label, value labels and user defined missing values
 #'
 #' Use `remove_var_label()` to remove variable label, `remove_val_labels()`
-#' to remove value labels, `remove_user_na()` to remove user defined missing values (*na_values* and *na_range*)
-#' and `remove_labels()` to remove all.
+#' to remove value labels, `remove_user_na()` to remove user defined missing
+#' values (*na_values* and *na_range*) and `remove_labels()` to remove all.
 #'
 #' @param x A vector or a data frame.
 #' @param user_na_to_na Convert user defined missing values into `NA`?
-#' @param user_na_to_tagged_na Convert user defined missing values into tagged `NA`?
-#' It could be applied only to numeric vectors. Note that integer labelled vectors
-#' will be converted to double labelled vectors.
+#' @param user_na_to_tagged_na Convert user defined missing values into
+#' tagged `NA`? It could be applied only to numeric vectors. Note that integer
+#' labelled vectors will be converted to double labelled vectors.
 #' @param keep_var_label Keep variable label?
 #' @details
-#' Be careful with `remove_user_na()` and `remove_labels()`, user defined missing values
-#' will not be automatically converted to `NA`, except if you specify
-#' `user_na_to_na = TRUE`.
-#' `user_na_to_na(x)` is an equivalent of `remove_user_na(x, user_na_to_na = TRUE)`.
+#' Be careful with `remove_user_na()` and `remove_labels()`, user defined
+#' missing values will not be automatically converted to `NA`, except if you
+#' specify `user_na_to_na = TRUE`.
+#' `user_na_to_na(x)` is an equivalent of
+#' `remove_user_na(x, user_na_to_na = TRUE)`.
 #'
-#' If you prefer to convert variables with value labels into factors, use [to_factor()]
-#' or use [unlabelled()].
+#' If you prefer to convert variables with value labels into factors, use
+#' [to_factor()] or use [unlabelled()].
 #' @examples
 #' x <- labelled_spss(1:10, c(Good = 1, Bad = 8), na_values = c(9, 10))
 #' var_label(x) <- "A variable"
@@ -31,8 +32,7 @@
 remove_labels <- function(x,
                           user_na_to_na = FALSE,
                           keep_var_label = FALSE,
-                          user_na_to_tagged_na = FALSE
-                          ) {
+                          user_na_to_tagged_na = FALSE) {
   UseMethod("remove_labels")
 }
 
@@ -41,8 +41,7 @@ remove_labels <- function(x,
 remove_labels.default <- function(x,
                                   user_na_to_na = FALSE,
                                   keep_var_label = FALSE,
-                                  user_na_to_tagged_na = FALSE
-                                  ) {
+                                  user_na_to_tagged_na = FALSE) {
   if (!keep_var_label) var_label(x) <- NULL
   val_labels(x) <- NULL
   attr(x, "format.spss") <- NULL
@@ -53,8 +52,7 @@ remove_labels.default <- function(x,
 remove_labels.haven_labelled_spss <- function(x,
                                               user_na_to_na = FALSE,
                                               keep_var_label = FALSE,
-                                              user_na_to_tagged_na = FALSE
-                                              ) {
+                                              user_na_to_tagged_na = FALSE) {
   x <- remove_user_na(
     x,
     user_na_to_na = user_na_to_na,
@@ -71,8 +69,7 @@ remove_labels.haven_labelled_spss <- function(x,
 remove_labels.data.frame <- function(x,
                                      user_na_to_na = FALSE,
                                      keep_var_label = FALSE,
-                                     user_na_to_tagged_na = FALSE
-                                     ) {
+                                     user_na_to_tagged_na = FALSE) {
   x[] <- lapply(
     x, remove_labels,
     user_na_to_na = user_na_to_na,
@@ -124,8 +121,7 @@ remove_val_labels.data.frame <- function(x) {
 #' @export
 remove_user_na <- function(x,
                            user_na_to_na = FALSE,
-                           user_na_to_tagged_na = FALSE
-                           ) {
+                           user_na_to_tagged_na = FALSE) {
   UseMethod("remove_user_na")
 }
 
@@ -133,8 +129,7 @@ remove_user_na <- function(x,
 #' @export
 remove_user_na.default <- function(x,
                                    user_na_to_na = FALSE,
-                                   user_na_to_tagged_na = FALSE
-                                   ) {
+                                   user_na_to_tagged_na = FALSE) {
   # do nothing
   x
 }
@@ -142,11 +137,13 @@ remove_user_na.default <- function(x,
 #' @export
 remove_user_na.haven_labelled_spss <- function(x,
                                                user_na_to_na = FALSE,
-                                               user_na_to_tagged_na = FALSE
-                                               ) {
+                                               user_na_to_tagged_na = FALSE) {
   if (user_na_to_tagged_na) {
-    if (typeof(x) == "character")
-      stop("'user_na_to_tagged_na' cannot be used with character labelled vectors.")
+    if (typeof(x) == "character") {
+      stop(
+        "'user_na_to_tagged_na' cannot be used with character labelled vectors."
+      )
+    }
 
     val_to_tag <- x[is.na(x) & !is.na(unclass(x))] %>%
       unclass() %>%
@@ -155,7 +152,8 @@ remove_user_na.haven_labelled_spss <- function(x,
 
     if (length(val_to_tag) > 26) {
       warning(
-        length(val_to_tag), " different user-defined missing values found in 'x'.\n",
+        length(val_to_tag),
+        " different user-defined missing values found in 'x'.\n",
         "A maximum of 26 could be tagged.\n",
         "'user_na_to_tagged_na' has been ignored.\n",
         "'user_na_to_na = TRUE' has been used instead."
@@ -171,7 +169,7 @@ remove_user_na.haven_labelled_spss <- function(x,
       user_na_to_na <- FALSE
       vl <- val_labels(x)
       x <- remove_user_na(x) # to avoid error when combining labelled_spss
-      for (i in 1:length(val_to_tag)) {
+      for (i in seq_along(val_to_tag)) {
         x[x == val_to_tag[i]] <- tagged_na(letters[i])
         if (val_to_tag[i] %in% vl) {
           vl[vl == val_to_tag[i]] <- tagged_na(letters[i])
@@ -183,8 +181,12 @@ remove_user_na.haven_labelled_spss <- function(x,
 
   if (user_na_to_na) {
     # removing value labels attached to user_na
-    for (val in val_labels(x)[test_if_user_na(val_labels(x), na_values(x), na_range(x))])
+    for (
+      val in
+      val_labels(x)[test_if_user_na(val_labels(x), na_values(x), na_range(x))]
+    ) {
       val_label(x, val) <- NULL
+    }
     x[is.na(x)] <- NA
   }
   na_values(x) <- NULL
@@ -195,8 +197,7 @@ remove_user_na.haven_labelled_spss <- function(x,
 #' @export
 remove_user_na.data.frame <- function(x,
                                       user_na_to_na = FALSE,
-                                      user_na_to_tagged_na = FALSE
-                                      ) {
+                                      user_na_to_tagged_na = FALSE) {
   x[] <- lapply(
     x,
     remove_user_na,
