@@ -1,6 +1,6 @@
 #' Recode values with no label to NA
 #'
-#' For labelled variables, values with no label will be recoded to \code{NA}.
+#' For labelled variables, values with no label will be recoded to `NA`.
 #'
 #' @param x Object to recode.
 #' @examples
@@ -21,8 +21,9 @@ nolabel_to_na.haven_labelled <- function(x) {
   allval <- unique(x)
   allval <- allval[!is.na(allval)]
   nolabel <- allval[!allval %in% val_labels(x)]
-  if (length(nolabel) > 0)
+  if (length(nolabel) > 0) {
     x[x %in% nolabel] <- NA
+  }
   x
 }
 
@@ -34,10 +35,10 @@ nolabel_to_na.data.frame <- function(x) {
 
 #' Recode value labels  to NA
 #'
-#' For labelled variables, values with a label will be recoded to \code{NA}.
+#' For labelled variables, values with a label will be recoded to `NA`.
 #'
 #' @param x Object to recode.
-#' @seealso \code{\link[haven]{zap_labels}}
+#' @seealso [haven::zap_labels()]
 #' @examples
 #' v <- labelled(c(1, 2, 9, 1, 9), c(dk = 9))
 #' val_labels_to_na(v)
@@ -54,8 +55,9 @@ val_labels_to_na.default <- function(x) {
 #' @export
 val_labels_to_na.haven_labelled <- function(x) {
   val <- val_labels(x)
-  if (length(val) > 0)
+  if (length(val) > 0) {
     x[x %in% val] <- NA
+  }
   val_labels(x) <- NULL
   x
 }
@@ -65,5 +67,3 @@ val_labels_to_na.data.frame <- function(x) {
   x[] <- lapply(x, val_labels_to_na)
   x
 }
-
-
